sbcl: a lisp compiler and runtime system
=====================================================================

Description
-----------

Steel Bank Common Lisp (SBCL) is a high performance Common Lisp compiler. It is
open source / free software, with a permissive license (see https://www.sbcl.org/history.html).
In addition to the compiler and runtime system for ANSI Common Lisp, it provides an interactive
environment including a debugger, a statistical profiler, a code coverage tool,
and many other extensions.

(taken from https://www.sbcl.org)

License
-------

- a mix of BSD-style and public domain


Upstream Contact
----------------

-  https://www.sbcl.org
